idea for different brands they may have unified design system to build up application, and also when we design mockups for new features, they may also need to follow design systems, so why not let's introduce the concept of themes.
- let's create a folder in docs called themes, it can contain may defined theme
- the naming convension for theme folder would be theme-{theme name}
- files contain in theme are:
  > design-system.md
  > compoent-visualiztion.html for different font size, font type, colors and basic components defined in design system.md

how to use themes
1. on x-ipe sidebar, we can have themes menu points to x-ipe-docs/themes
2. in toolbox modal window let's add themes section at top, you can reference toolbox feature to learn the mockup
3. create a skill x-ipe-tool-frontend-design which should minic the skill frontend-design, but base on the theme selected to get design-systems and  compoent-visualiztion to guide the design
4. in toolbox modal window, in ideation mock, we should able to have this tool for use.